import path from 'node:path';
import fs from 'node:fs';
import md5 from 'md5';
import { createContext } from './index.mjs';
import { e as ensureDir, v as version } from './shared/css-to-tailwindcss-plugin.9b36006e.mjs';
import 'node:fs/promises';
import 'postcss';
import 'postcss-import';
import '@babel/types';
import '@babel/generator';
import 'node:url';



// -- Unbuild CommonJS Shims --
import __cjs_url__ from 'url';
import __cjs_path__ from 'path';
import __cjs_mod__ from 'module';
const __filename = __cjs_url__.fileURLToPath(import.meta.url);
const __dirname = __cjs_path__.dirname(__filename);
const require = __cjs_mod__.createRequire(import.meta.url);
function generateTempPlugin(entry, p) {
  const ctx = createContext();
  ctx.processSync(entry);
  const code = ctx.generate();
  fs.writeFileSync(p, code, "utf8");
  return code;
}
function getDefaultCacheDir() {
  return path.resolve(process.cwd(), "node_modules", ".css-to-tailwindcss-plugin");
}
const tailwindcss = (options) => {
  const cacheDir = options.cacheDir ?? getDefaultCacheDir();
  ensureDir(cacheDir);
  const indexFilePath = path.resolve(cacheDir, "index.json");
  let hashMap = {};
  function loadCache() {
    if (fs.existsSync(indexFilePath)) {
      try {
        hashMap = JSON.parse(fs.readFileSync(indexFilePath, "utf8"));
      } catch {
        console.log(`parse json: ${indexFilePath} failed!`);
      }
    }
  }
  function writeCacheIndexFile(data) {
    data.version = version;
    fs.writeFileSync(indexFilePath, JSON.stringify(data), "utf8");
  }
  loadCache();
  const targetPlugins = [];
  const isSameVersion = hashMap.version === version;
  for (const entry of options.entries) {
    const fileHash = md5(entry);
    const cssHash = md5(fs.readFileSync(entry));
    const p = path.resolve(cacheDir, fileHash) + ".js";
    if (isSameVersion && fs.existsSync(p)) {
      if (hashMap[fileHash] !== cssHash) {
        generateTempPlugin(entry, p);
        hashMap[fileHash] = cssHash;
      }
    } else {
      generateTempPlugin(entry, p);
      hashMap[fileHash] = cssHash;
    }
    targetPlugins.push(p);
  }
  writeCacheIndexFile(hashMap);
  return targetPlugins.map((x) => require(x));
};

export { tailwindcss as default };
